<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Gateway Documentation

- **[codespace-gateway.md](codespace-gateway.md)** — implementing codespace SSH operations, working with the Codespace gateway ABC, testing code that executes commands on codespaces, adding new codespace operations
- **[codespace-registry.md](codespace-registry.md)** — working with GitHub Codespaces, implementing codespace registration, managing remote execution environments
